<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="目标年度">
              <el-date-picker v-model="querys[0].value" placeholder="请选择目标年度" style="width:100%;" type="year"
                              value-format="yyyy" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="目标名称">
              <el-input v-model="querys[1].value" clearable placeholder="请输入目标名称" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="安全业务分类" prop="saftyClass">
              <el-select v-model="querys[2].value" clearable placeholder="请选择安全业务分类" size="small">
                <el-option v-for="item in aqywlbList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" style="margin-left: 10px"
                     type="danger">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData" :header-cell-style="{ 'text-align': 'center' }"
                :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                size="mini" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed label="序号" type="index" width="55"></el-table-column>
        <el-table-column label="目标年度" min-width="70" prop="targetYear" show-overflow-tooltip
                         sortable></el-table-column>
        <el-table-column label="目标名称" min-width="120" prop="name" show-overflow-tooltip></el-table-column>
        <el-table-column label="安全业务分类" min-width="100" prop="saftyClassName"
                         show-overflow-tooltip></el-table-column>
        <el-table-column label="目标说明" min-width="150" prop="content" show-overflow-tooltip></el-table-column>
        <el-table-column label="相关依据描述" min-width="150" prop="according" show-overflow-tooltip></el-table-column>
        <el-table-column label="是否考核" min-width="60" prop="targetIsCheck" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page" :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" align="right"
                     background
                     class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
    </div>
    <CmgtSaftyTargetFormDialog ref="formModal"></CmgtSaftyTargetFormDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'

import CmgtSaftyTargetApi from '@/views/Manage/saftyPlan/api/CmgtSaftyTargetApi'
import CmgtSaftyTargetFormDialog from '@/views/Manage/saftyPlan/components/CmgtSaftyTargetFormDialog'

export default {
  name: 'CmgtSaftyTargetManage',
  components: {
    CmgtSaftyTargetFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyTarget/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'target_year_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'safty_class_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      aqywlbList: []
    }
  },
  created() {
    this.aqywlbList = dictUtils.getDictItemsFromCache('aqywlb')
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      CmgtSaftyTargetApi.loadCmgtSaftyTarget(this.queryParam, res => {
        //console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          this.aqywlbList.forEach(val => {
            if (item.saftyClass == val.value) {
              item['saftyClassName'] = val.name
            }
          })
        })

        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log('猜测是是', row)
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },

    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
